@@ -1,11 +1,10 @@
 /* apt-dater - terminal-based remote package update manager
  *
  * Authors:
- *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008-2012 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2015 (C) IBH IT-Service GmbH [https://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -26,8 +25,9 @@
 #ifndef _KEYFILES_H
 #define _KEYFILES_H
 
-GList *loadHosts (char *filename);
-CfgFile *loadConfig (char *filename);
+CfgFile *initialConfig();
+GList *loadHosts (const char *filename);
+gboolean loadConfig (const char *filename, CfgFile *);
 void freeConfig (CfgFile *cfg);
 int chkForInitialConfig(const gchar *, const gchar *);
 
