@@ -1,11 +1,10 @@
 /* apt-dater - terminal-based remote package update manager
  *
  * Authors:
- *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008-2012 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2015 (C) IBH IT-Service GmbH [https://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -55,6 +54,7 @@ void initReport(GList *hosts) {
   if (writer == NULL)
     g_error(_("Error creating the xml output."));
   xmlTextWriterStartDocument(writer, NULL, NULL, NULL);
+  xmlTextWriterWriteDTD(writer, BAD_CAST("report"), NULL, BAD_CAST(XML_SCHEMA_URI"/report.dtd"), NULL);
 
   if(!hosts) return;
 
@@ -139,6 +139,8 @@ static void reportHost(gpointer data, gpointer lgroup) {
   /* Begin host element. */  
   xmlTextWriterStartElement(writer, BAD_CAST("host"));
   xmlTextWriterWriteAttribute(writer, BAD_CAST("hostname"), BAD_CAST(n->hostname));
+  if(n->comment)
+    xmlTextWriterWriteAttribute(writer, BAD_CAST("comment"), BAD_CAST(n->comment));
 #ifdef FEAT_TCLFILTER
   if(n->filtered)
     xmlTextWriterWriteAttribute(writer, BAD_CAST("filtered"), BAD_CAST("1"));
@@ -154,16 +156,16 @@ static void reportHost(gpointer data, gpointer lgroup) {
   xmlTextWriterStartElement(writer, BAD_CAST("ssh"));
   if(n->ssh_user)
     xmlTextWriterWriteElement(writer, BAD_CAST("user"), BAD_CAST(n->ssh_user));
+  if(n->ssh_host)
+    xmlTextWriterWriteFormatElement(writer, BAD_CAST("host"), "%s", n->ssh_host);
   if(n->ssh_port)
     xmlTextWriterWriteFormatElement(writer, BAD_CAST("port"), "%d", n->ssh_port);
   xmlTextWriterEndElement(writer);
 
   /* Kernel info */
   xmlTextWriterStartElement(writer, BAD_CAST("kernel"));
-  if(n->status & HOST_STATUS_KERNELNOTMATCH)
+  if(n->status & (HOST_STATUS_KERNELABIUPGR | HOST_STATUS_KERNELVERUPGR))
     xmlTextWriterWriteAttribute(writer, BAD_CAST("reboot"), BAD_CAST("1"));
-  if(n->status & HOST_STATUS_KERNELSELFBUILD)
-    xmlTextWriterWriteAttribute(writer, BAD_CAST("custom"), BAD_CAST("1"));
   if(n->kernelrel)
     xmlTextWriterWriteString(writer, BAD_CAST(n->kernelrel));
   xmlTextWriterEndElement(writer);
@@ -198,7 +200,7 @@ static void reportHost(gpointer data, gpointer lgroup) {
 
 #ifdef FEAT_HISTORY
   /* history data */
-  GList *hel = history_get_entries(n);
+  GList *hel = history_get_entries(cfg, n);
   if(hel) {
     xmlTextWriterStartElement(writer, BAD_CAST("history"));
     g_list_foreach(hel, reportHistory, NULL);
