@@ -1,11 +1,10 @@
 /* apt-dater - terminal-based remote package update manager
  *
  * Authors:
- *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008-2012 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2015 (C) IBH IT-Service GmbH [https://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -34,6 +33,8 @@
 # include "config.h"
 #endif
 
+#ifndef FEAT_TMUX
+
 #include "screen.h"
 #include "parsecmd.h"
 #include "history.h"
@@ -42,14 +43,23 @@ static struct passwd *pw = NULL;
 
 const static gchar *
 screen_get_sdir() {
-  static gchar sdir[256];
+  static gchar sdir[PATH_MAX];
 
+  if (g_strcmp0(getenv("SCREENDIR"), NULL) != 0) {
+    g_strlcpy(sdir, sizeof(sdir), getenv("SCREENDIR"));
+    return sdir;
+  }
+
+#ifndef __APPLE__
   if (!pw)
     pw = getpwuid(getuid());
   if (!pw)
     return NULL;
 
   g_snprintf(sdir, sizeof(sdir), SCREEN_SDFORMT, SCREEN_SOCKPATH, pw->pw_name);
+#else
+  g_snprintf(sdir, sizeof(sdir), SCREEN_SDFORMT, SCREEN_SOCKPATH);
+#endif
 
   return sdir;
 }
@@ -90,6 +100,7 @@ screen_get_sessions(HostNode *n) {
 #endif
 	s->pid = pid;
 	stat(fn, &s->st);
+	s->attached = s->st.st_mode & S_IXUSR;
 
 	n->screens = g_list_prepend(n->screens, s);
       }
@@ -104,38 +115,43 @@ screen_get_sessions(HostNode *n) {
   return g_list_length(n->screens) > 0;
 }
 
-gchar *
+gchar **
 screen_new(HostNode *n, const gboolean detached) {
+  gchar **_argv = (gchar **) g_malloc0(sizeof(gchar *) * 8);
   gchar *title = parse_string(cfg->screentitle, n);
 
-  gchar *cmd = g_strdup_printf(SCREEN_BINARY"+-%sS+"SCREEN_SOCKPRE"%s_%s_%d"	\
-			       "+-t+%s+-c+%s+",
-			       detached ? "dm" : "",
-			       n->ssh_user, n->hostname, n->ssh_port,
-			       title,
-			       cfg->screenrcfile);
+  _argv[0] = g_strdup(SCREEN_BINARY);
+  _argv[1] = g_strdup_printf("-%sS", detached ? "dm" : "");
+  _argv[2] = g_strdup_printf(SCREEN_SOCKPRE"%s_%s_%d", n->ssh_user,
+			     n->hostname, 
+			     n->ssh_port);
+  _argv[3] = g_strdup("-t");
+  _argv[4] = title;
+  _argv[5] = g_strdup("-c");
+  _argv[6] = g_strdup(cfg->screenrcfile);
 
-  g_free(title);
-
-  return cmd;
+  return _argv;
 }
 
-static gchar *
+static gchar **
 screen_attach_cmd(const SessNode *s, const gboolean shared) {
-  return g_strdup_printf(SCREEN_BINARY"+-r%s+%d+", shared ? "x" : "", s->pid);
+  gchar **_argv = (gchar **) g_malloc0(sizeof(gchar *) * 4);
+
+  _argv[0] = g_strdup(SCREEN_BINARY);
+  _argv[1] = g_strdup_printf("-r%s", shared ? "x" : "");
+  _argv[2] = g_strdup_printf("%d", s->pid);
+
+  return _argv;
 }
 
 gboolean
 screen_attach(HostNode *n, const SessNode *s, const gboolean shared) {
  gboolean r;
  GError *error = NULL;
- gchar *cmd = screen_attach_cmd(s, shared);
- gchar **argv = NULL;
+ gchar **argv = screen_attach_cmd(s, shared);
 
  g_assert(n);
 
- argv = g_strsplit(cmd, "+", 0);
-
  r = g_spawn_sync(g_getenv ("HOME"), argv, NULL, 
 		  G_SPAWN_CHILD_INHERITS_STDIN, NULL, NULL,
 		  NULL, NULL, NULL, &error);
@@ -145,45 +161,46 @@ screen_attach(HostNode *n, const SessNode *s, const gboolean shared) {
   g_clear_error (&error);
  }
 
- g_free(cmd);
  g_strfreev(argv);
 
 #ifdef FEAT_HISTORY
  if(n->parse_result && !screen_get_sessions(n)) {
     n->parse_result = FALSE;
-    return history_ts_failed(n);
+    return history_ts_failed(cfg, n);
  }
 #endif
 
  return FALSE;
 }
 
-static gchar *
+static gchar **
 screen_dump_cmd(const SessNode *s, const gchar *fn) {
-  return g_strdup_printf(SCREEN_BINARY"+-S+%d+-X+hardcopy+%s", s->pid, fn);
+  gchar **_argv = (gchar **) g_malloc0(sizeof(gchar *) * 7);
+
+  _argv[0] = g_strdup(SCREEN_BINARY);
+  _argv[1] = g_strdup("-S");
+  _argv[2] = g_strdup_printf("%d", s->pid);
+  _argv[3] = g_strdup("-X");
+  _argv[4] = g_strdup("hardcopy");
+  _argv[5] = g_strdup(fn);
+  _argv[6] = NULL;
+
+  return _argv;
 }
 
 gchar *
 screen_get_dump(const SessNode *s) {
  gboolean r;
  GError *error = NULL;
- gchar **argv = NULL;
 
  gchar *dump_fn = g_strdup_printf("%s/dump-XXXXXX", g_get_tmp_dir());
  gint fd = g_mkstemp(dump_fn);
 
+ gchar **argv = screen_dump_cmd(s, dump_fn);
+
  if(fd == -1)
    return NULL;
 
- gchar *cmd = screen_dump_cmd(s, dump_fn);
- if(!cmd) {
-  g_unlink(dump_fn);
-  close(fd);
-  return NULL;
- }
-
- argv = g_strsplit(cmd, "+", 0);
-
  r = g_spawn_sync(g_getenv ("HOME"), argv, NULL, 
 		  G_SPAWN_CHILD_INHERITS_STDIN, NULL, NULL,
 		  NULL, NULL, NULL, &error);
@@ -193,7 +210,6 @@ screen_get_dump(const SessNode *s) {
   g_clear_error (&error);
  }
 
- g_free(cmd);
  g_strfreev(argv);
 
  gchar *c = NULL;
@@ -205,3 +221,4 @@ screen_get_dump(const SessNode *s) {
 
  return c;
 }
+#endif /* !FEAT_TMUX */
