@@ -1,11 +1,10 @@
 /* apt-dater - terminal-based remote package update manager
  *
  * Authors:
- *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008-2012 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2015 (C) IBH IT-Service GmbH [https://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -26,25 +25,27 @@
 #ifndef _SCREEN_H
 #define _SCREEN_H
 
+#include "config.h"
+
+#ifndef FEAT_TMUX
+
 #include "apt-dater.h"
 #include "history.h"
 
+#ifndef __APPLE__
 #define SCREEN_SDFORMT "%s/S-%s"
+#else
+#define SCREEN_SDFORMT "%s/.screen"
+#endif
 #define SCREEN_SOCKPRE "apt-dater_"
 
 gboolean
 screen_get_sessions(HostNode *n);
 
-gchar *screen_new(HostNode *n, const gboolean detached);
+gchar **screen_new(HostNode *n, const gboolean detached);
 gboolean screen_attach(HostNode *n, const SessNode *s, const gboolean shared);
 gchar *screen_get_dump(const SessNode *s);
 
-static inline gboolean
-screen_is_attached(const SessNode *s) {
-  if (s->st.st_mode & S_IXUSR)
-    return TRUE;
-
-  return FALSE;
-}
+#endif /* !FEAT_TMUX */
 
 #endif /* _SCREEN_H */
